==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/ja.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "リンク:",
    "Password:" : "パスワード:",
    "Generating system report failed." : "システムレポートの生成に失敗しました。",
    "Subscription notifications" : "サブスクリプションのお知らせ",
    "Could not create folder \"System information\" to store generated report." : "生成されたレポートを格納するための\"システム情報\"フォルダ を作成できませんでした。",
    "Could not share file \"%s\"." : "ファイル \"%s\" を共有できません。",
    "Nextcloud Subscription" : "Nextcloudサブスクリプション",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "サーバーにNextcloudサブスクリプションがないか、サブスクリプションの有効期限が切れています。",
    "Your Nextcloud server subscription does not cover your number of users." : "Nextcloudサーバーサブスクリプションが、ユーザー数に不足しています。",
    "Your Nextcloud Subscription has expired!" : "サブスクリプションの有効期限が切れています！",
    "Your server has no Nextcloud Subscription" : "サーバーにNextcloudサブスクリプションがありません",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Nextcloudサーバーが、Nextcloudエンタープライズサブスクリプションによってサポートされていません。",
    "Thank you," : "ありがとう。",
    "Your Nextcloud team" : "あなたのNextcloudチーム",
    "Your Nextcloud server Subscription is expired" : "サーバーのサブスクリプションの有効期限が切れています！",
    "Your Nextcloud server Subscription is expired!" : "サーバーのサブスクリプションの有効期限が切れています！",
    "Support" : "サポート",
    "Basic subscription" : "ベーシックサブスクリプション",
    "Standard subscription" : "スタンダードサブスクリプション",
    "Premium subscription" : "プレミアムサブスクリプション",
    "Géant subscription" : "大型サブスクリプション",
    "Silver partner subscription" : "シルバーパートナーサブスクリプション",
    "Gold partner subscription" : "ゴールドパートナーサブスクリプション",
    "Subscription" : "サブスクリプション",
    "Over subscription limit" : "サブスクリプション制限の超過",
    "Valid subscription" : "正当なサブスクリプション",
    "Expired subscription" : "期限切れのサブスクリプション",
    "Subscription key:" : "サブスクリプションキー:",
    "_Expires in %n year_::_Expires in %n years_" : ["%n 年で期限が切れます"],
    "_Expires in %n month_::_Expires in %n months_" : ["%n ヶ月で期限が切れます"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["%n週で期限が切れます"],
    "_Expires in %n day_::_Expires in %n days_" : ["%n日で期限が切れます"],
    "Update subscription key" : "サブスクリプションキーを更新する",
    "Access Nextcloud portal" : "Nextcloudポータルにアクセスする",
    "System information" : "システム情報",
    "Generate system report" : "システムレポートを生成する",
    "Unsupported" : "サポートされていません。",
    "Get a quote" : "見積もりを取得する",
    "More information" : "詳細情報",
    "Subscription benefits" : "サブスクリプションのメリット",
    "Pricing" : "価格",
    "Commmunity support" : "コミュニティサポート",
    "Forum" : "フォーラム",
    "GitHub" : "GitHub",
    "Chat" : "チャット",
    "Nextcloud forum" : "Nextcloudフォーラム",
    "Nextcloud at GitHub" : "Nextcloud at GitHub",
    "Open chat" : "チャットを始める",
    "Subscription key" : "サブスクリプションキー",
    "Learn more about an enterprise subscription." : "エンタープライズサブスクリプションについて学ぶ",
    "Set subscription key" : "Nextcloudサブスクリプションのキーをセット",
    "News" : "ニュース",
    "Follow us on Google+" : "Google+でフォロー！",
    "Like our Facebook page" : "私たちのFacebookのページをイイネ！",
    "Follow us on Twitter" : "Twitter でフォロー！",
    "Check out our blog" : "私たちのブログを見てね！",
    "Subscribe to our newsletter" : "ニュースレターを購読する！"
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/ja.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "リンク:",
    "Password:" : "パスワード:",
    "Generating system report failed." : "システムレポートの生成に失敗しました。",
    "Subscription notifications" : "サブスクリプションのお知らせ",
    "Could not create folder \"System information\" to store generated report." : "生成されたレポートを保存するための\"システム情報\"フォルダーを作成できませんでした。",
    "Could not create file \"%s\" to store generated report." : "生成されたレポートを保存するための\"%s\"ファイルを作成できませんでした。",
    "Could not share file \"%s\"." : "ファイル \"%s\" を共有できません。",
    "Nextcloud Subscription" : "Nextcloudサブスクリプション",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "サーバーにNextcloudサブスクリプションがないか、サブスクリプションの有効期限が切れています。",
    "Your Nextcloud server subscription does not cover your number of users." : "Nextcloudサーバーサブスクリプションが、ユーザー数に不足しています。",
    "Your Nextcloud Subscription has expired!" : "サブスクリプションの有効期限が切れています！",
    "Your server has no Nextcloud Subscription" : "サーバーにNextcloudサブスクリプションがありません",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Nextcloudサーバーが、Nextcloudエンタープライズサブスクリプションによってサポートされていません。",
    "Learn more now" : "今すぐもっと見る",
    "Thank you," : "ありがとう。",
    "Your Nextcloud team" : "あなたのNextcloudチーム",
    "Your Nextcloud server Subscription is expired" : "サーバーのサブスクリプションの有効期限が切れています！",
    "Your Nextcloud server Subscription is expired!" : "サーバーのサブスクリプションの有効期限が切れています！",
    "Support" : "サポート",
    "Basic subscription" : "ベーシックサブスクリプション",
    "Standard subscription" : "スタンダードサブスクリプション",
    "Premium subscription" : "プレミアムサブスクリプション",
    "Géant subscription" : "大型サブスクリプション",
    "Silver partner subscription" : "シルバーパートナーサブスクリプション",
    "Gold partner subscription" : "ゴールドパートナーサブスクリプション",
    "Subscription" : "サブスクリプション",
    "Over subscription limit" : "サブスクリプション制限の超過",
    "Valid subscription" : "正当なサブスクリプション",
    "Expired subscription" : "期限切れのサブスクリプション",
    "Subscription key:" : "サブスクリプションキー:",
    "_Expires in %n year_::_Expires in %n years_" : ["%n 年で期限が切れます"],
    "_Expires in %n month_::_Expires in %n months_" : ["%n ヶ月で期限が切れます"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["%n週で期限が切れます"],
    "_Expires in %n day_::_Expires in %n days_" : ["%n日で期限が切れます"],
    "Update subscription key" : "サブスクリプションキーを更新する",
    "Access Nextcloud portal" : "Nextcloudポータルにアクセスする",
    "System information" : "システム情報",
    "Generate system report" : "システムレポートを生成する",
    "Unsupported" : "サポートされていません。",
    "Get a quote" : "見積もりを取得する",
    "More information" : "詳細情報",
    "Subscription benefits" : "サブスクリプションのメリット",
    "Pricing" : "価格",
    "Commmunity support" : "コミュニティサポート",
    "Forum" : "フォーラム",
    "GitHub" : "GitHub",
    "Chat" : "チャット",
    "Nextcloud forum" : "Nextcloudフォーラム",
    "Nextcloud at GitHub" : "Nextcloud at GitHub",
    "Open chat" : "チャットを始める",
    "Subscription key" : "サブスクリプションキー",
    "Learn more about an enterprise subscription." : "エンタープライズサブスクリプションについて学ぶ",
    "Set subscription key" : "Nextcloudサブスクリプションのキーを設定",
    "News" : "ニュース",
    "Like our Facebook page" : "私たちのFacebookのページをイイネ！",
    "Follow us on Twitter" : "Twitter でフォロー！",
    "Check out our blog" : "私たちのブログを見てね！",
    "Subscribe to our newsletter" : "ニュースレターを購読する！"
},
"nplurals=1; plural=0;");
